```
Usage: vcd gateway configure-external-network add [OPTIONS] <name>

Options:
  -e, --external-network <external network>
                                  external network to which the gateway can
                                  connect.  [required]
  --configure-ip-setting <subnet> <configured IP>
                                  configuring multiple IP settings
  -h, --help                      Show this message and exit.

```
